@@ -110,6 +110,7 @@ class GDPSInstaller extends React.Component<
           : false,
       sshUsername: '',
       sshKeyfile: '',
+      dbuser: '',
       tg_cluster_mode: false
     };
 
@@ -139,7 +140,11 @@ class GDPSInstaller extends React.Component<
     });
   }
 
-  handleSSH(state: { sshUsername: string; sshKeyfile: string }): void {
+  handleSSH(state: {
+    sshUsername: string;
+    sshKeyfile: string;
+    dbuser: string;
+  }): void {
     this.setState(state);
     this.setState({ renderView: 'toInstall' });
   }
@@ -166,9 +171,10 @@ class GDPSInstaller extends React.Component<
       '{ tg_output_path=' + this.state.tg_output_path.trim(),
       'local_output_path=' + this.state.local_output_path.trim(),
       'tg_cluster_mode=' + this.state.tg_cluster_mode.toString(),
-      'tg_host=' + this.props.serverAddress.includes('https')
-        ? this.props.serverAddress
-        : 'http://localhost',
+      'tg_host=' +
+        (this.props.serverAddress.includes('https')
+          ? this.props.serverAddress
+          : 'http://localhost'),
       'tg_rest_port=' + this.props.restPort,
       'tg_gs_port=' + this.props.gsqlPort,
       'nohup ./' +
@@ -180,15 +186,14 @@ class GDPSInstaller extends React.Component<
     ];
     this.setState({ renderView: 'installing' });
 
+    const sshPrefix =
+      ssh.join(' ') +
+      (this.state.dbuser && this.state.dbuser !== this.state.sshUsername
+        ? ' -t "su - ' + this.state.dbuser + ' -c '
+        : ' "bash -i -c ');
     const exec = this.state.isLocalInstall
       ? cmds.join(' ') + '\n'
-      : ssh.join(' ') +
-        ' "bash -i -c ' +
-        "'" +
-        cmds.join(' ') +
-        "'" +
-        '"' +
-        '\n';
+      : sshPrefix + "'" + cmds.join(' ') + "'" + '"' + '\n';
     const commands = this.props.jupyterApp.commands;
     commands.execute('terminal:create-new').then(model => {
       const terminal = model.content;
@@ -276,7 +281,7 @@ class GDPSInstaller extends React.Component<
             the right and install GDPS to the server. Continue?
           </p>
           <button onClick={this.handleInstall}>Yes!</button>
-          <button onClick={this.props.handleExit}>hmm, maybe later</button>
+          <button onClick={this.props.handleExit}>Hmm, maybe later</button>
         </div>
       );
     } else if (this.state.renderView === 'installing') {
@@ -324,6 +329,7 @@ class VolumeMountForm extends React.Component<VolumeMountFormProps> {
           name="volumeMount"
           placeholder="/folder/on/host:/folder/in/container"
           defaultValue=""
+          required
         />
         <button type="submit">Next</button>
       </form>
@@ -359,8 +365,9 @@ class TmpOutputForm extends React.Component<TmpOutputFormProps> {
         <input
           type="text"
           name="tmpOutput"
-          placeholder="/home/tigergraph/tmp"
-          defaultValue=""
+          placeholder="/home/tigergraph/gdpstmp"
+          defaultValue="/home/tigergraph/gdpstmp"
+          required
         />
         <button type="submit">Next</button>
       </form>
@@ -379,10 +386,12 @@ class SSHForm extends React.Component<SSHFormProps> {
     const target = event.target as typeof event.target & {
       username: { value: string };
       keyfile: { value: string };
+      dbuser: { value: string };
     };
     this.props.update({
       sshUsername: target.username.value.trim(),
-      sshKeyfile: target.keyfile.value.trim()
+      sshKeyfile: target.keyfile.value.trim(),
+      dbuser: target.dbuser.value.trim()
     });
   }
 
@@ -390,21 +399,29 @@ class SSHForm extends React.Component<SSHFormProps> {
     return (
       <form onSubmit={this.handleSubmit}>
         <p>
-          Finally, we will use SSH to install GDPS onto the server. Please
-          provide your SSH credentials (no sudo needed). If using password for
-          SSH, leave the private key blank and you will be prompted to enter
-          password next on the terminal.
+          Finally, we will SSH into the server and install GDPS. Please provide
+          your SSH credentials (no sudo needed) and the database username. If
+          the database and SSH usernames are the same, leave the database
+          username blank. A termial will open on the right showing the progress
+          and asking for password if needed.
         </p>
         <input
           type="text"
           name="username"
-          placeholder="username"
+          placeholder="ssh username"
           defaultValue=""
+          required
         />
         <input
           type="text"
           name="keyfile"
-          placeholder="path to key file"
+          placeholder="path to ssh key file"
+          defaultValue=""
+        />
+        <input
+          type="text"
+          name="dbuser"
+          placeholder="database username"
           defaultValue=""
         />
         <br />
